(*
 * Copyright (C) 2003:
 *    Stefano Zacchiroli <zack@cs.unibo.it>
 *    for the HELM Team http://helm.cs.unibo.it/
 *
 *  This file is part of HELM, an Hypertextual, Electronic
 *  Library of Mathematics, developed at the Computer Science
 *  Department, University of Bologna, Italy.
 *
 *  HELM is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  HELM is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with HELM; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA  02111-1307, USA.
 *
 *  For details, see the HELM World-Wide-Web page,
 *  http://helm.cs.unibo.it/
 *)

open Uwobo_common ;;

  (**
    @param logger logger for processing messages
    @param styles stylesheets object
    @param keys (ordered) list of stylesheet names to be applied
    @param params function mapping stylesheet names to parameters list
    @param props xml:output properties
    @param errormode what to do with LibXSLT's error messages
    @param debugmode what to do with LibXSLT's debugging messages
    @param input URI of input document
    @return a triple: 1st element is a function that takes an out_channel and
    write the result document on it, 2nd element is a string option representing
    the desired media-type, 3rd is a string option representing the desired
    encoding
  *)
val apply:
  logger: Uwobo_logger.sysLogger ->
  styles: Uwobo_styles.styles ->
  keys: string list ->
  params: (string -> (string * string) list) ->
  props: (string * string) list ->
  veillogger: Uwobo_common.libXsltLogger ->
  ?errormode: xslt_msg_mode -> ?debugmode: xslt_msg_mode ->
  Gdome.document ->
    ((out_channel -> unit) * string option * string option)

