(*
 * Copyright (C) 2003:
 *    Stefano Zacchiroli <zack@cs.unibo.it>
 *    for the HELM Team http://helm.cs.unibo.it/
 *
 *  This file is part of HELM, an Hypertextual, Electronic
 *  Library of Mathematics, developed at the Computer Science
 *  Department, University of Bologna, Italy.
 *
 *  HELM is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  HELM is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with HELM; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA  02111-1307, USA.
 *
 *  For details, see the HELM World-Wide-Web page,
 *  http://helm.cs.unibo.it/
 *)

open Uwobo_common ;;

exception Stylesheet_not_found of string ;;
exception Stylesheet_already_in of string ;;

  (** hold UWOBO styles at runtime *)
class styles:
  object

    (** {2 Stylesheets management} *)

      (** add a stylesheet, bound to a given key, to the UWOBO loaded
      stylesheets
      @param key key to which the stylesheets will be bound
      @param uri uri of the stylesheet to be loaded
      @raise Stylesheet_already_in if key is already bound *)
    method add: string -> string -> unit

      (** remove the stylesheet bound to a given key *)
    method remove: string -> unit

      (** remove all loaded stylesheet *)
    method removeAll: unit

      (** reload the stylesheet bound to a given key *)
    method reload: string -> unit

      (** reload all stylesheets *)
    method reloadAll: unit

    (** {2 Stylesheets usage} *)

      (** @return the list of currently loaded stylesheets' keys *)
    method keys: string list

      (** @return a list of strings, each string is a textual representation of
      information related to a loaded stylesheet. This representation includes
      at least stylesheet's key and URI *)
    method list: string list

      (**
      @param key_list non empty list of keys
      @param props list of prop
      @param logger the logger to be used to report errors and warnings
      @return a pair. The first argument of the pair is an association list
      that maps given keys to gdome2-xslt processed stylesheets. The last
      stylesheet xsl:output element is modified according to the given
      properties. The second argument of the pair is the last unprocessed
      stylesheet.
      *)
    method get:
      string list -> (string * string) list -> Uwobo_logger.sysLogger ->
        (string * I_gdome_xslt.processed_stylesheet) list * Gdome.document

  end

